lilypondparsertools.LilyPondParser
==================================

.. abjad-lineage:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser

.. autoclass:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.available_languages
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.debug
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.default_language
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.lexer
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.lexer_rules_object
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_contexts
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_dynamics
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_grobs
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_languages
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_markup_functions
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_music_functions
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.logger
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.logger_path
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.output_path
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.parser
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.parser_rules_object
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.pickle_path
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.register_markup_function
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.tokenize
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__call__
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__eq__
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__format__
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__hash__
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__ne__
      ~abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__repr__

Bases
-----

- :py:class:`abctools.Parser <abjad.tools.abctools.Parser.Parser>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.available_languages
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.debug
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.lexer
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.lexer_rules_object
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.logger
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.logger_path
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.output_path
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.parser
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.parser_rules_object
   :noindex:

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.pickle_path
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.default_language
   :noindex:

Methods
-------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.tokenize
   :noindex:

Class methods
-------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.register_markup_function
   :noindex:

Static methods
--------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_contexts
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_dynamics
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_grobs
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_languages
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_markup_functions
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.list_known_music_functions
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__call__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__format__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__hash__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondParser.LilyPondParser.__repr__
   :noindex:
